#!/bin/bash
# checkinstall - check prerequisites before (eventually) executing
# Syntax: checkinstall package1 package2 ... -- command options...


PATH="/bin:/sbin:/usr/bin:/usr/sbin"
export PATH

XDIALOG_HIGH_DIALOG_COMPAT=1
export XDIALOG_HIGH_DIALOG_COMPAT

XDIALOG_NO_GMSGS=1
export XDIALOG_NO_GMSGS

[ "`id -u`" != "0" ] && exec sudo -H "$0" "$@"

TMP="/tmp/knoppix-checkinstall.tmp.$$"

bailout(){
 rm -f "$TMP"
 exit $1
}

# Simple shell grep
stringinfile(){
 case "$(cat $2)" in *$1*) return 0;; esac
 return 1
}

# Not yet installed requirements
REQ=()
count=0
installonly="true"

while [ -n "$1" ]; do
 arg="$1"; shift
 case "$arg" in  --) installonly=""; break;; esac
 [ -f /var/lib/dpkg/info/"$arg".list ] && continue
 REQ[$((count++))]="$arg"
done

cmd="$1"

# Language-specific messages
if [ -r /etc/sysconfig/i18n ]; then
 . /etc/sysconfig/i18n
elif [ -r /etc/default/locale ]; then
 . /etc/default/locale
fi

# Temporary workaround
case "$LANG" in de*.UTF-8) LANG="de_DE@euro";; esac

case "$LANGUAGE" in
 de*)
  TITLE="Installations-Check"
  BACKTITLE="Automatische berprfung der Software-Installation"
  MESSAGE="
Um das Programm '$cmd' im vollen Umfang nutzen zu knnen, sollten noch $count Softwarepakete installiert werden:
${REQ[@]}

Pakete jetzt installieren?"
  SUCCESS="Installation erfolgreich."
  FAILED="INSTALLATION FEHLGESCHLAGEN."
  ;;
 *)
  TITLE="Checking Installation"
  BACKTITLE="Automatic Check of Software Installation"
  MESSAGE="
In order to use program '$cmd' without restrictions, these other $count packages should also be installed:
${REQ[@]}

Install them now?"
  SUCCESS="Installation successful."
  FAILED="INSTALLATION FAILED."
  ;;
esac

# Dialogs
if [ -n "$DISPLAY" ] && type zenity >/dev/null 2>&1; then
 ICON="/usr/share/icons/checkinstall.xpm"
 [ -r "$ICON" ] && ICON="--window-icon=$ICON" || ICON=""
 yesno(){
  zenity --question --title="$TITLE" $ICON --text="$BACKTITLE\n\n$1"
  return $?
 }
else
 yesno(){
  dialog --title "$TITLE" --backtitle "$BACKTITLE" --yesno  "$1" 15 65
  return $?
 }
fi
# END Dialogs

install_packages(){
 local XSHELL=()
 if type -p urxvt >&/dev/null; then
  XSHELL=( urxvt -T "$TITLE" -e )
 elif type -p rxvt >&/dev/null; then
  XSHELL=( rxvt -T "$TITLE" -e )
 elif type -p xterm >&/dev/null; then
  XSHELL=( xterm -T "$TITLE" -e )
 fi
 rm -f "$TMP"
 echo '#!/bin/bash
export PATH="/bin:/sbin:/usr/bin:/usr/sbin"
sudo -H apt-get -y update
sudo -H apt-get -y install '"$*"'
if [ "$?" = "0" ]; then
 type -p zenity >/dev/null 2>&1 && exec zenity --info --timeout=5 --title="'"$TITLE"'" '"$ICON"' --text="'"$SUCCESS"'"
else
 type -p zenity >/dev/null 2>&1 && exec zenity --error --title="'"$TITLE"'" '"$ICON"' --text="'"$FAILED"'"
fi' >"$TMP"
 chmod 755 "$TMP"
 "${XSHELL[@]}" "$TMP"
 rm -f "$TMP"
}

if [ -z "$cmd" -a "$count" = "0" ]; then
 echo "Syntax: $0 package1 package2 ... -- Kommando Optionen...
Prft, ob die angegebenen Pakete installiert sind und installiert
sie auf Wunsch, anschlieend wird das angegebene Programm gestartet." >&2
 bailout 1
fi 

if [ "$count" -gt 0 ]; then
 { [ -n "$installonly" ] || yesno "$MESSAGE"; } && install_packages "${REQ[@]}"
fi

[ -n "$*" ] && exec "$@"
